@@ -1,8 +1,8 @@
 echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
 echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
 echo "" 												>> $EXTENSION/build_order.txt
-
-if [ $BUILD_ALL == "false" ] && [[ $(pkg-config gettext --modversion 2>/dev/null) != "0.22" ]]; then
+	
+if [ $BUILD_ALL == "false" ] && [[ $(command -v gettext) == "" ]]; then
 	echo "gettext" 										>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
